use bevy::{asset::AssetPath, prelude::*};

use crate::debug::{ConsoleLog, DebugEvent, DebugMode};

pub fn plugin(app: &mut App) {
    app.add_systems(
        Update,
        handle_load_gltf.run_if(in_state(DebugMode::Enabled)),
    );
}

fn handle_load_gltf(
    mut c: Commands,
    mut dbg_reader: EventReader<DebugEvent>,
    mut logger: ResMut<ConsoleLog>,
    asset_server: Res<AssetServer>,
) {
    for ev in dbg_reader.read() {
        if let DebugEvent::LoadGltf { asset_path } = ev {
            let scene_handle = asset_server
                .load(GltfAssetLabel::Scene(0).from_asset(AssetPath::from(asset_path.clone())));

            c.spawn(SceneRoot(scene_handle));
        }
    }
}
